# Credits

This package was created with the [audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage) project template.

## Contributors

- Raymond Wanyoike <raymond.wanyoike@gmail.com>
